from .ZFPEmulator import ZFPEmulator
from .FiltersEmulator import FilterEmulator
from .LibpressioEmulator import LibpressioEmulator

# Define the default emulator
default_emulator = FilterEmulator
